==> jc-1.4.0.tar.gz: soot/grimp/internal/GTrap.h <==
// public class soot.grimp.internal.GTrap

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 29fff555fe64e924 soot_AbstractTrap
// @dep_class 86e181f3ef77edf5 soot_grimp_internal_GTrap

// header file dependencies
// @dep_header soot_AbstractTrap

#include "soot/AbstractTrap.h"

#ifndef _JC_soot_grimp_internal_GTrap_H_
#define _JC_soot_grimp_internal_GTrap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GTrap$sub_refs	_jc_soot_grimp_internal_GTrap$sub_refs;
typedef struct _jc_soot_grimp_internal_GTrap$sub_nonrefs	_jc_soot_grimp_internal_GTrap$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GTrap$refs	_jc_soot_grimp_internal_GTrap$refs;
typedef struct _jc_soot_grimp_internal_GTrap$nonrefs	_jc_soot_grimp_internal_GTrap$nonrefs;
typedef struct _jc_soot_grimp_internal_GTrap$object	_jc_soot_grimp_internal_GTrap$object;

typedef const struct _jc_soot_grimp_internal_GTrap$vmethods	_jc_soot_grimp_internal_GTrap$vmethods;
typedef const struct _jc_soot_grimp_internal_GTrap$vtable	_jc_soot_grimp_internal_GTrap$vtable;
typedef const struct _jc_soot_grimp_internal_GTrap$vtype	_jc_soot_grimp_internal_GTrap$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GTrap$method$_init$a95ad0a460493016(_jc_env *, struct _jc_soot_grimp_internal_GTrap$object *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GTrap$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GTrap$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GTrap$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GTrap$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GTrap$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GTrap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractTrap$vmethods	soot_AbstractTrap;
	_jc_soot_grimp_internal_GTrap$vmethods	soot_grimp_internal_GTrap;
};

// Vtype
struct _jc_soot_grimp_internal_GTrap$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GTrap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GTrap$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GTrap$refs {
    _jc_soot_grimp_internal_GTrap$sub_refs	soot_grimp_internal_GTrap;
    _jc_soot_AbstractTrap$sub_refs	soot_AbstractTrap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GTrap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GTrap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractTrap$sub_nonrefs	soot_AbstractTrap;
    _jc_soot_grimp_internal_GTrap$sub_nonrefs	soot_grimp_internal_GTrap;
};

// Object instance structure
struct _jc_soot_grimp_internal_GTrap$object {
	_jc_soot_grimp_internal_GTrap$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GTrap$vtype	*vtype;
	_jc_soot_grimp_internal_GTrap$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GTrap$vtype _jc_soot_grimp_internal_GTrap$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GTrap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GTrap$class_object;

#endif	/* _JC_soot_grimp_internal_GTrap_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GTrap.h <==
// public class soot.grimp.internal.GTrap

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 29fff555fe64e924 soot_AbstractTrap
// @dep_class 86e181f3ef77edf5 soot_grimp_internal_GTrap

// header file dependencies
// @dep_header soot_AbstractTrap

#include "soot/AbstractTrap.h"

#ifndef _JC_soot_grimp_internal_GTrap_H_
#define _JC_soot_grimp_internal_GTrap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GTrap$sub_refs	_jc_soot_grimp_internal_GTrap$sub_refs;
typedef struct _jc_soot_grimp_internal_GTrap$sub_nonrefs	_jc_soot_grimp_internal_GTrap$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GTrap$refs	_jc_soot_grimp_internal_GTrap$refs;
typedef struct _jc_soot_grimp_internal_GTrap$nonrefs	_jc_soot_grimp_internal_GTrap$nonrefs;
typedef struct _jc_soot_grimp_internal_GTrap$object	_jc_soot_grimp_internal_GTrap$object;

typedef const struct _jc_soot_grimp_internal_GTrap$vmethods	_jc_soot_grimp_internal_GTrap$vmethods;
typedef const struct _jc_soot_grimp_internal_GTrap$vtable	_jc_soot_grimp_internal_GTrap$vtable;
typedef const struct _jc_soot_grimp_internal_GTrap$vtype	_jc_soot_grimp_internal_GTrap$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GTrap$method$_init$a95ad0a460493016(_jc_env *, struct _jc_soot_grimp_internal_GTrap$object *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GTrap$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GTrap$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GTrap$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GTrap$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GTrap$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GTrap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractTrap$vmethods	soot_AbstractTrap;
	_jc_soot_grimp_internal_GTrap$vmethods	soot_grimp_internal_GTrap;
};

// Vtype
struct _jc_soot_grimp_internal_GTrap$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GTrap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GTrap$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GTrap$refs {
    _jc_soot_grimp_internal_GTrap$sub_refs	soot_grimp_internal_GTrap;
    _jc_soot_AbstractTrap$sub_refs	soot_AbstractTrap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GTrap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GTrap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractTrap$sub_nonrefs	soot_AbstractTrap;
    _jc_soot_grimp_internal_GTrap$sub_nonrefs	soot_grimp_internal_GTrap;
};

// Object instance structure
struct _jc_soot_grimp_internal_GTrap$object {
	_jc_soot_grimp_internal_GTrap$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GTrap$vtype	*vtype;
	_jc_soot_grimp_internal_GTrap$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GTrap$vtype _jc_soot_grimp_internal_GTrap$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GTrap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GTrap$class_object;

#endif	/* _JC_soot_grimp_internal_GTrap_H_ */
